@@ -169,8 +169,10 @@ class Operator:
                                                                       parameters_map)
         self.grounded_add_effects = self.ground_predicates(self.action.add_effects, parameters_map)
         self.grounded_delete_effects = self.ground_predicates(self.action.delete_effects, parameters_map)
-        self.grounded_equality_preconditions = self.ground_equality_objects(self.action.equality_preconditions, parameters_map)
-        self.grounded_inequality_preconditions = self.ground_equality_objects(self.action.inequality_preconditions, parameters_map)
+        self.grounded_equality_preconditions = self.ground_equality_objects(self.action.equality_preconditions,
+                                                                            parameters_map)
+        self.grounded_inequality_preconditions = self.ground_equality_objects(self.action.inequality_preconditions,
+                                                                              parameters_map)
 
         self.grounded_numeric_preconditions = self.ground_numeric_expressions(self.action.numeric_preconditions,
                                                                               parameters_map)
@@ -245,7 +247,7 @@ class Operator:
 
         # Checking for objects equality.
         if len(self.grounded_equality_preconditions) > 0 and \
-            not self._equality_holds(self.grounded_equality_preconditions) or \
+                not self._equality_holds(self.grounded_equality_preconditions) or \
                 len(self.grounded_inequality_preconditions) > 0 and \
                 self._equality_holds(self.grounded_inequality_preconditions):
             return False
@@ -286,15 +288,9 @@ class Operator:
         self.logger.info("Applying the action on the state predicates.")
         next_state_predicates = {}
         for lifted_predicate_name, grounded_predicates in previous_state.state_predicates.items():
-            next_state_predicates[lifted_predicate_name] =\
+            next_state_predicates[lifted_predicate_name] = \
                 set([GroundedPredicate(p.name, p.signature, p.object_mapping) for p in grounded_predicates])
 
-        grouped_add_effects = self._group_effect_predicates(self.grounded_add_effects)
-        self.logger.debug("Adding the new predicates according to the add effects.")
-        for lifted_predicate_str, grounded_predicates in grouped_add_effects.items():
-            updated_predicates = next_state_predicates.get(lifted_predicate_str, set()).union(grounded_predicates)
-            next_state_predicates[lifted_predicate_str] = updated_predicates
-
         grouped_delete_effects = self._group_effect_predicates(self.grounded_delete_effects)
         self.logger.debug("Removing state predicates according to the delete effects.")
         for lifted_predicate_str, grounded_predicates in grouped_delete_effects.items():
@@ -311,6 +307,12 @@ class Operator:
 
             next_state_predicates[lifted_predicate_str] = next_state_grounded_predicates
 
+        grouped_add_effects = self._group_effect_predicates(self.grounded_add_effects)
+        self.logger.debug("Adding the new predicates according to the add effects.")
+        for lifted_predicate_str, grounded_predicates in grouped_add_effects.items():
+            updated_predicates = next_state_predicates.get(lifted_predicate_str, set()).union(grounded_predicates)
+            next_state_predicates[lifted_predicate_str] = updated_predicates
+
         return next_state_predicates
 
     def update_state_functions(self, previous_state: State) -> Dict[str, PDDLFunction]:
